@@ -11,5 +11,9 @@ from continuum.datasets.nlp import MultiNLI
 from continuum.datasets.pytorch import (
     CIFAR10, CIFAR100, EMNIST, KMNIST, MNIST, QMNIST, FashionMNIST
 )
+from continuum.datasets.svhn import SVHN
 from continuum.datasets.pascalvoc import PascalVOC2012
 from continuum.datasets.stream51 import Stream51
+from continuum.datasets.dtd import DTD
+from continuum.datasets.rainbow_mnist import RainbowMNIST
+from continuum.datasets.ctrl import CTRL, CTRLplus, CTRLminus, CTRLin, CTRLout, CTRLplastic
