@@ -1,5 +1,6 @@
 import abc
 from typing import List, Tuple, Union
+import warnings
 
 import numpy as np
 from torchvision import datasets as torchdata
@@ -69,21 +70,28 @@ class _SemanticSegmentationDataset(_ContinuumDataset):
 
 class PyTorchDataset(_ContinuumDataset):
     """Continuum version of torchvision datasets.
-
     :param dataset_type: A Torchvision dataset, like MNIST or CIFAR100.
+    :param train: train flag
+    :param download: download
     """
 
     # TODO: some datasets have a different structure, like SVHN for ex. Handle it.
     def __init__(
-        self, data_path: str = "", dataset_type=None, train: bool = True, download: bool = True
-    ):
+            self, data_path: str = "", dataset_type=None, train: bool = True, download: bool = True, **kwargs):
         super().__init__(data_path=data_path, train=train, download=download)
-
         self.dataset_type = dataset_type
-        self.dataset = self.dataset_type(self.data_path, download=self.download, train=self.train)
+        self.dataset = self.dataset_type(self.data_path, download=self.download, train=self.train, **kwargs)
 
     def get_data(self) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
         x, y = np.array(self.dataset.data), np.array(self.dataset.targets)
+
+        if 0 not in y:
+            # This case can happen when the first class id is 1 and not 0.
+            # For example in EMNIST with 'letters' split (WTF right).
+            # TODO: We should handle this case in a more generic fashion later.
+            warnings.warn("Converting 1-based class ids to 0-based class ids.")
+            y -= 1
+
         return x, y, None
 
 
@@ -97,13 +105,13 @@ class InMemoryDataset(_ContinuumDataset):
     """
 
     def __init__(
-        self,
-        x: np.ndarray,
-        y: np.ndarray,
-        t: Union[None, np.ndarray] = None,
-        data_type: str = "image_array",
-        train: bool = True,
-        download: bool = True,
+            self,
+            x: np.ndarray,
+            y: np.ndarray,
+            t: Union[None, np.ndarray] = None,
+            data_type: str = "image_array",
+            train: bool = True,
+            download: bool = True,
     ):
         super().__init__(train=train, download=download)
 
@@ -141,7 +149,6 @@ class ImageFolderDataset(_ContinuumDataset):
         self.data_path = data_path
         super().__init__(data_path=data_path, train=train, download=download)
 
-
         allowed_data_types = ("image_path", "segmentation")
         if data_type not in allowed_data_types:
             raise ValueError(f"Invalid data_type={data_type}, allowed={allowed_data_types}.")
